@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Util qw(decamelize class_to_path);
 File::Spec::Functions->import(qw(catfile catdir));
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub register {
   my ($self, $app) = @_;
@@ -12,6 +12,7 @@ sub register {
   # to $app->static->paths if needed
   #unshift @{$app->static->paths},   app->home->rel_dir('path/to/other/public/files');
   $self->_add_paths($app);
+  return;
 }
 
 # Add Plugin specific paths in case they differ from $app paths.
@@ -40,7 +41,9 @@ sub _add_paths {
 
   return;
 }
+
 1;
+
 __END__
 
 =encoding utf8
@@ -61,33 +64,61 @@ Mojolicious::Plugin::SemanticUI - Mojolicious Plugin
   <head>
   <!-- ... -->
   %= stylesheet begin
-    @import url('/vendor/Semantic-UI/minified/definitions/elements/button.min.css');
-    @import url('/vendor/Semantic-UI/minified/definitions/elements/divider.min.css');
+    @import url('/vendor/SemanticUI/minified/definitions/elements/button.min.css');
+    @import url('/vendor/SemanticUI/minified/definitions/elements/divider.min.css');
   %=end
-  %= javascript '/vendor/Semantic-UI/packaged/definitions/javascript/semantic.min.js'
+  %= javascript '/vendor/SemanticUI/packaged/definitions/javascript/semantic.min.js'
   <!-- ... -->
   </head>
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::SemanticUI> provides helpers for using Semantic UI library. It also includes the library it self.
-You do not need to download Semantic UI it separately.
-This is ALPHA release, not ready for production.
+L<Mojolicious::Plugin::SemanticUI> 
+includes the minifed build of the Semantic UI CSS and Javascript library.
+Note that the beta 1.0 version is included - L<http://beta.semantic-ui.com/>.
+It also provides helpers for using Semantic UI modules in your temmplates (views). 
+This way you do not need to download Semantic UI it separately.
+This is ALPHA release - B<not ready for production>.
 
 =head1 METHODS
 
 L<Mojolicious::Plugin::SemanticUI> inherits all methods from
 L<Mojolicious::Plugin> and implements the following new ones.
+
 =head2 register
 
   $plugin->register(Mojolicious->new);
 
 Register plugin in L<Mojolicious> application.
 
+=head1 HELPERS
+
+L<Mojolicious::Plugin::SemanticUI> B<will> exports the following
+helpers for use in controllers and templates.
+The helpers are provided in the C<SemanticUI> namespace.
+
+  % my $sui = $c->SemanticUI;
+  %= $sui->segment begin
+    Ала-бала-ница, турска паница,
+    Хей гиди Ванчо,
+    наш капитанчо...
+  %=end
+
+=head2 segment
+
+TODO
+...
+
+
 =head1 SEE ALSO
+
 L<http://beta.semantic-ui.com/>,
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
 
+=head1 AUTHOR
+
+Красимир Беров (Krasimir Berov)
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2014 Красимир Беров (Krasimir Berov).
